@@ -1,5 +1,8 @@
 # -*- coding: utf-8 -*-
-import cStringIO
+from six import print_, reraise
+from six import BytesIO, StringIO
+from six import b, u
+
 import pexpect
 import re
 import sys
@@ -28,12 +31,13 @@ class CommandWithExpect(object):
         self.expect_delay = expect_delay
         self.log = create_logger(None, debug_enabled)
         self.expect_patterns = [
-            '^Enter passphrase.+',
-            '[Pp]assword.*:',
-            'パスワード', # TODO: japanese character expected as utf-8
+            b('^Enter passphrase.+'),
+            b('[Pp]assword.*:'),
+            u('パスワード').encode('utf-8'), # TODO: japanese character expected as utf-8
         ]
         if expect_out is None:
-            expect_out = cStringIO.StringIO()
+            #expect_out = StringIO()
+            expect_out = BytesIO()
         if expect is None:
             self.expect = pexpect.spawn(
                 command,
@@ -52,7 +56,6 @@ class CommandWithExpect(object):
         
         Returns: command result status, output string
         """
-
         try:
             index = self.expect.expect(self.expect_patterns)
             self.log.debug("expect index = %d" % (index))
@@ -60,7 +63,7 @@ class CommandWithExpect(object):
             if index in (0, 1, 2):
                 if password is None:
                     self.log.debug("Password is None")
-                    #print >> stderr, "[error] Password is empty. Use -l or -s"
+                    #print_('[error] Password is empty. Use -l or -s', file=stderr)
                     raise CommandError("Password is empty. Use -l/--prompt-login-password or --login-password-stdin.")
 
                 if index == 0:
@@ -83,9 +86,10 @@ class CommandWithExpect(object):
             raise TimeoutError("Execution is timed out after %d seconds" % (self.timeout))
         except pexpect.EOF:
             self.log.debug("expect.EOF")
-        except CommandError, e:
-            raise e, None, sys.exc_info()[2]
-
+        except CommandError:
+            e = sys.exc_info()[1]
+            #raise(e, None, sys.exc_info()[2])
+            reraise(*sys.exc_info())
         return self.get_status_and_output(self.expect, self.expect_out)
 
     def get_status_and_output(self, child, expect_out):
@@ -100,7 +104,7 @@ class CommandWithExpect(object):
         self.log.debug("exit_status = %d" % exit_status)
 
         output_lines = []
-        expect_regexs = [ re.compile(p) for p in self.expect_patterns ]
+        expect_regexs = [ re.compile(p.decode('utf-8')) for p in self.expect_patterns ]
         expect_regexs.append(re.compile('Connection to .* closed'))
 
         passwords = []
@@ -108,7 +112,11 @@ class CommandWithExpect(object):
             passwords.append(self.login_password)
         if self.sudo_password:
             passwords.append(self.sudo_password)
-        for line in expect_out.getvalue().split('\n'):
+        #print("--- bytes ---")
+        #print(expect_out.getvalue())
+        lines = expect_out.getvalue().decode("utf-8").split('\n')
+        #for line in expect_out.getvalue().split('\n'):
+        for line in lines:
             line = line.strip('\r\n')
             if line == '' or line in passwords:
                 continue
