@@ -1,6 +1,7 @@
 import logging
+import sys
 
-def create_logger(debug_enabled=False, deep_debug_enabled=False):
+def create_logger(file_path = None, debug_enabled = False, deep_debug_enabled = False):
     level = logging.INFO
     if debug_enabled:
         level = logging.DEBUG
@@ -8,8 +9,11 @@ def create_logger(debug_enabled=False, deep_debug_enabled=False):
         format = "[%(levelname)s] %(filename)s:%(lineno)d %(message)s"
     else:
         format = "[%(levelname)s] %(message)s"
-    logging.basicConfig(
-        level = level,
-        format = format
-    )
+
+    kwargs = { 'level': level, 'format': format }
+    if file_path:
+        kwargs['filename'] = file_path
+    else:
+        kwargs['stream'] = sys.stdout
+    logging.basicConfig(**kwargs)
     return logging
